@@ -1,6 +1,3 @@
-import numpy as np
-import os
-
 from .iari import renameh
 from .iari import unziph
 from .iari import raw2nph
