@@ -1,6 +1,6 @@
 import numpy as np
 
-def rawread(path,height,width):
+def read_raw(path,height,width):
     '''this fucion read raw files . Made by sunny arya .It takes three arguments  path, height and width.
     Parameters
     ----------
